@@ -1,30 +1,31 @@
 package PNI::Slot;
 use PNI::Mo;
-use Scalar::Util;
 extends 'PNI::Elem';
 
+use Scalar::Util;
+
 has data => ();
 has node => ();
 
-sub is_array { shift->type eq 'ARRAY' ? 1 : 0 }
+sub is_array { return shift->type eq 'ARRAY' ? 1 : 0; }
 
-sub is_code { shift->type eq 'CODE' ? 1 : 0 }
+sub is_code { return shift->type eq 'CODE' ? 1 : 0; }
 
-sub is_defined { shift->type eq 'UNDEF' ? 0 : 1 }
+sub is_defined { return defined( shift->data ); }
 
-sub is_hash { shift->type eq 'HASH' ? 1 : 0 }
+sub is_hash { return shift->type eq 'HASH' ? 1 : 0; }
 
-sub is_number { Scalar::Util::looks_like_number( shift->data ) ? 1 : 0 }
+sub is_number { return Scalar::Util::looks_like_number( shift->data ) ? 1 : 0 }
 
-sub is_scalar { shift->type eq 'SCALAR' ? 1 : 0 }
+sub is_scalar { return shift->type eq 'SCALAR' ? 1 : 0; }
 
 sub is_string {
     my $self = shift;
     $self->is_scalar or return 0;
-    $self->is_number ? 0 : 1;
+    return $self->is_number ? 0 : 1;
 }
 
-sub is_undef { shift->type eq 'UNDEF' ? 1 : 0 }
+sub is_undef { return shift->type eq 'UNDEF' ? 1 : 0; }
 
 sub type {
     my $data = shift->data;
@@ -32,7 +33,8 @@ sub type {
     return ref $data || 'SCALAR';
 }
 
-1
+1;
+
 __END__
 
 =head1 NAME
@@ -45,23 +47,25 @@ PNI::Slot - is a basic unit of data
 
 =head2 node
 
+    my $node = $slot->node;
+
 =head1 METHODS
 
-=head1 is_array
+=head2 is_array
 
-=head1 is_code
+=head2 is_code
 
-=head1 is_defined
+=head2 is_defined
 
-=head1 is_hash
+=head2 is_hash
 
-=head1 is_number
+=head2 is_number
 
-=head1 is_scalar
+=head2 is_scalar
 
-=head1 is_string
+=head2 is_string
 
-=head1 is_undef
+=head2 is_undef
 
 =head2 translate
 
